# ChainerX

This is the C++ code base for ChainerX including the Python bindings.

For instructions how to build and install it, please refer to the [ChainerX contribution guide](../docs/source/chainerx/contribution.rst).
